@@ -408,15 +408,14 @@ player_open (Player     *player,
       g_free (unesc);
       return FALSE;
     }
-  else
-    {
-      g_timer_stop (priv->timer);
-      g_timer_reset (priv->timer);
-      priv->timer_add = 0;
-    }
-  
+
+  g_timer_stop (priv->timer);
+  g_timer_reset (priv->timer);
+  priv->timer_add = 0;
+
   g_free (priv->current_file);
   priv->current_file = g_strdup (uri);
+
   return TRUE;
 }
 
@@ -440,7 +439,7 @@ player_set_file (Player *player,
 		 char      **error)
 {
   PlayerPriv *priv;
-  char *escaped;
+  char *uri;
 
   g_return_val_if_fail (IS_PLAYER (player), FALSE);
 
@@ -448,14 +447,19 @@ player_set_file (Player *player,
 
   *error = NULL;
 
-  escaped = gnome_vfs_escape_path_string (file);
-  if (!player_open (player, escaped, error))
+  uri = gnome_vfs_get_uri_from_local_path (file);
+  if (uri == NULL)
     {
-      g_free (escaped);
+      *error = g_strdup ("Failed to convert filename to URI.");
+      return FALSE;
+    }
+  else if (!player_open (player, uri, error))
+    {
+      g_free (uri);
       return FALSE;
     }
 
-  g_free (escaped);
+  g_free (uri);
 
   return TRUE;
 }
@@ -498,6 +502,10 @@ player_stop (Player *player)
   g_free (priv->current_file);
   priv->current_file = NULL;
 
+  g_timer_stop (priv->timer);
+  g_timer_reset (priv->timer);
+  priv->timer_add = 0;
+
   if (priv->stream != NULL)
     {
       xine_stop (priv->stream);
